@@ -1300,7 +1300,6 @@ class yhgit:
         # 子目录，用来存放子模块仓库, 如果没有需要创建一个
         if os.path.exists(local_yaml_path):
             os.remove(local_yaml_path)
-            return
         modules_path = "modules/"
         if os.path.exists(modules_path):
             del_file(modules_path)
@@ -1322,22 +1321,24 @@ def main(argvs=None):
         argvs = sys.argv
     print(argvs)
     # 获取指令类型
-    command = argvs[2]
+    command = argvs[1]
     branchname = ''
     modules = []
-    print(command)
+    debugInfo(len(argvs))
+    debugInfo(command)
+    print(command == "clean")
     if command == "install":
         print(len(argvs))
-        if len(argvs) > 3:
-            subcommand = argvs[3]
+        if len(argvs) > 2:
+            subcommand = argvs[2]
             if subcommand and len(subcommand) > 0 and subcommand == "-b":
                 # 需要获取具体的分支名
-                branchname = argvs[4]
+                branchname = argvs[3]
                 if branchname and len(branchname) > 0:
                     # 获取需要创建分支的组件
-                    modules = argvs[5:]
+                    modules = argvs[4:]
             else:
-                modules = argvs[3:]
+                modules = argvs[2:]
 
         if not (branchname and len(branchname) > 0):
             # 获取本地配置的分支名称
@@ -1361,11 +1362,11 @@ def main(argvs=None):
         yhgit().status()
     elif command == "commit":
         commit_msg = ''
-        if len(argvs) > 3:
-            subcommand = argvs[3]
+        if len(argvs) > 2:
+            subcommand = argvs[2]
             if subcommand and len(subcommand) > 0 and subcommand == "-m":
                 # 需要获取具体的分支名
-                commit_msg = argvs[4]
+                commit_msg = argvs[3]
         if not (commit_msg and len(commit_msg) > 0):
             debugInfo("必须添加-m 和 commit_msg")
         else:
